@@ -19,9 +19,12 @@ def get_limit_from_url(objects):
     """
     import urllib.parse as urlparse
 
-    url = objects.json()["_links"]["self"]["href"]
-    par = urlparse.parse_qs(urlparse.urlparse(url).query)
-    return int(par["limit"][0])
+    try:
+        url = objects.json()["_links"]["self"]["href"]
+        par = urlparse.parse_qs(urlparse.urlparse(url).query)
+        return int(par["limit"][0])
+    except KeyError:
+        return 50
 
 
 def process_json(data, entity):
@@ -40,18 +43,18 @@ class AmocrmApiLoader(AmocrmApiLoaderBase, ABC):
     """
 
     def __init__(
-        self,
-        entity,
-        s3_client,
-        args_api,
-        date_modified_from=None,
-        batch_api=250,
-        is_oauth2=True,
+            self,
+            entity,
+            s3_client,
+            args_api,
+            date_modified_from=None,
+            batch_api=250,
+            is_oauth2=True,
     ):
         """
         :param entity:   amocrm entities contacts/users/accounts e.t.c
         :param s3_client: s3 client from talenttech-oss library
-        :param args_api: dict with AMO_USER_LOGIN/AMO_USER_HASH/AMO_AUTH_URL
+        :param args_api: dict with
         :param date_modified_from:
         :param batch_api: size of batch to upload
         """
@@ -136,4 +139,3 @@ class AmocrmApiLoader(AmocrmApiLoaderBase, ABC):
                 "Total number of rows received from API is %d", self.rows_to_upload
             )
             num_url += 1
-
